# AutoTau 文档

此目录包含AutoTau库的文档。

## 文档内容

- [API参考文档](api_reference.md)：详细介绍了各个类和方法的用法

## 文档构建

目前文档以Markdown格式提供。未来可能会添加使用Sphinx或其他工具构建的更完整的文档。

## 贡献文档

如果您发现文档中的错误或想要改进文档，欢迎提交Pull Request或创建Issue。 